package de.hft.stuttgart.citydoctor2.check.error;

import java.util.List;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.GmlElement;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;


/**
 * If a polygon is fully inside a solid geometry this error is created.
 * 
 * @author Alexander Riegel
 */
public class InteriorFaceError implements CheckError{

	
	private static final long serialVersionUID = 6633158315015689806L;
	
	private List<Polygon> polygons;
	private Geometry geom;
	
	
	
	public InteriorFaceError(Geometry geom, List<Polygon> polygons) {
		super();
		this.polygons = polygons;
		this.geom = geom;
	}

	public Geometry getGeometry() {
		return geom;
	}
	
	public List<Polygon> getPolygons(){
		return polygons;
	}
	@Override
	public ErrorType getType() {
		return ErrorType.ERROR;
	}

	@Override
	public ErrorId getErrorId() {
		return ErrorId.GE_S_INTERIOR_FACE;
	}

	@Override
	public GmlElement getFeature() {
		return getGeometry();
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}
	
	public String toString() {
		return "InteriorFaceError [Polygons=" + polygons + ", geom=" + geom + "]";
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public void report(ErrorReport report) {
		report.add(geom);
		polygons.forEach(x -> report.add(x)); 
		
	}

}
